@@ -6,7 +6,7 @@
 
 package Lemonldap::NG::Manager::Build::Attributes;
 
-our $VERSION = '1.9.5';
+our $VERSION = '1.9.6';
 use strict;
 use Regexp::Common qw/URI/;
 
@@ -480,6 +480,12 @@ sub attributes {
             default       => 0,
             documentation => 'Session activity timeout on server side',
         },
+        timeoutActivityInterval => {
+            type          => 'int',
+            test          => sub { $_[0] >= 0 },
+            default       => 60,
+            documentation => 'Update session timeout interval on server side',
+        },
         trustedProxies => {
             type          => 'text',
             default       => '',
@@ -510,6 +516,10 @@ sub attributes {
             default       => 'uid',
             documentation => 'Session parameter used to fill REMOTE_USER',
         },
+        lwpSslOpts => {
+            type          => 'keyTextContainer',
+            documentation => 'Options given to LWP::UserAgent',
+        },
 
         # History
         failedLoginNumber => {
@@ -1465,7 +1475,7 @@ sub attributes {
         },
         samlIDPMetaDataOptionsCheckSSOMessageSignature => {
             type    => 'bool',
-            default => 0,
+            default => 1,
         },
         samlIDPMetaDataOptionsSignSLOMessage => {
             type    => 'trool',
@@ -1473,7 +1483,7 @@ sub attributes {
         },
         samlIDPMetaDataOptionsCheckSLOMessageSignature => {
             type    => 'bool',
-            default => 0,
+            default => 1,
         },
         samlIDPMetaDataOptionsSSOBinding => {
             type   => 'select',
@@ -1508,7 +1518,23 @@ sub attributes {
             ],
             default => 'none',
         },
-        samlIDPMetaDataOptionsCheckConditions => {
+        samlIDPMetaDataOptionsCheckTime => {
+            type    => 'bool',
+            default => 1,
+        },
+        samlIDPMetaDataOptionsCheckAudience => {
+            type    => 'bool',
+            default => 1,
+        },
+        samlIDPMetaDataOptionsResolutionRule => {
+            type    => 'longtext',
+            default => '',
+        },
+        samlIDPMetaDataOptionsStoreSAMLToken => {
+            type    => 'bool',
+            default => 0,
+        },
+        samlIDPMetaDataOptionsRelayStateURL => {
             type    => 'bool',
             default => 0,
         },
@@ -1617,7 +1643,7 @@ sub attributes {
         },
         samlSPMetaDataOptionsCheckSSOMessageSignature => {
             type    => 'bool',
-            default => 0,
+            default => 1,
         },
         samlSPMetaDataOptionsSignSLOMessage => {
             type    => 'trool',
@@ -1625,7 +1651,7 @@ sub attributes {
         },
         samlSPMetaDataOptionsCheckSLOMessageSignature => {
             type    => 'bool',
-            default => 0,
+            default => 1,
         },
         samlSPMetaDataOptionsEncryptionMode => {
             type   => 'select',
@@ -2362,8 +2388,9 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
           { type => 'bool', default => 1 },
         oidcOPMetaDataOptionsIDTokenMaxAge => { type => 'int',  default => 30 },
         oidcOPMetaDataOptionsUseNonce      => { type => 'bool', default => 1 },
-        oidcOPMetaDataOptionsDisplayName => { type => 'text', },
-        oidcOPMetaDataOptionsIcon        => { type => 'text', },
+        oidcOPMetaDataOptionsDisplayName  => { type => 'text', },
+        oidcOPMetaDataOptionsIcon         => { type => 'text', },
+        oidcOPMetaDataOptionsStoreIDToken => { type => 'bool', default => 0 },
 
         # OpenID Connect relying parties
         oidcRPMetaDataExportedVars => {
@@ -2396,8 +2423,9 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
           { type => 'int', default => 3600 },
         oidcRPMetaDataOptionsAccessTokenExpiration =>
           { type => 'int', default => 3600 },
-        oidcRPMetaDataOptionsRedirectUris => { type => 'text', },
-        oidcRPMetaDataOptionsExtraClaims  => { type => 'keyTextContainer', },
+        oidcRPMetaDataOptionsRedirectUris  => { type => 'text', },
+        oidcRPMetaDataOptionsExtraClaims   => { type => 'keyTextContainer', },
+        oidcRPMetaDataOptionsBypassConsent => { type => 'bool', default => 0 },
 
     };
 }
