@@ -37,12 +37,14 @@ sub cTrees {
                 help  => 'authsaml.html#options',
                 form  => 'simpleInputContainer',
                 nodes => [
+                    'samlIDPMetaDataOptionsResolutionRule',
                     'samlIDPMetaDataOptionsNameIDFormat',
                     'samlIDPMetaDataOptionsForceAuthn',
                     'samlIDPMetaDataOptionsIsPassive',
                     'samlIDPMetaDataOptionsAllowProxiedAuthn',
                     'samlIDPMetaDataOptionsAllowLoginFromIDP',
                     'samlIDPMetaDataOptionsRequestedAuthnContext',
+                    'samlIDPMetaDataOptionsRelayStateURL',
                 ],
             },
             {
@@ -50,7 +52,8 @@ sub cTrees {
                 form  => 'simpleInputContainer',
                 nodes => [
                     "samlIDPMetaDataOptionsAdaptSessionUtime",
-                    "samlIDPMetaDataOptionsForceUTF8"
+                    "samlIDPMetaDataOptionsForceUTF8",
+                    "samlIDPMetaDataOptionsStoreSAMLToken"
                 ]
             },
             {
@@ -76,7 +79,8 @@ sub cTrees {
                 form  => 'simpleInputContainer',
                 nodes => [
                     "samlIDPMetaDataOptionsEncryptionMode",
-                    "samlIDPMetaDataOptionsCheckConditions"
+                    "samlIDPMetaDataOptionsCheckTime",
+                    "samlIDPMetaDataOptionsCheckAudience"
                 ]
             }
         ],
@@ -95,7 +99,8 @@ sub cTrees {
                             "samlSPMetaDataOptionsNameIDSessionKey",
                             "samlSPMetaDataOptionsOneTimeUse",
                             "samlSPMetaDataOptionsSessionNotOnOrAfterTimeout",
-                            "samlSPMetaDataOptionsNotOnOrAfterTimeout"
+                            "samlSPMetaDataOptionsNotOnOrAfterTimeout",
+                            "samlSPMetaDataOptionsForceUTF8"
                         ]
                     },
                     {
@@ -133,7 +138,8 @@ sub cTrees {
                             'oidcOPMetaDataOptionsConfigurationURI',
                             'oidcOPMetaDataOptionsJWKSTimeout',
                             'oidcOPMetaDataOptionsClientID',
-                            'oidcOPMetaDataOptionsClientSecret'
+                            'oidcOPMetaDataOptionsClientSecret',
+                            'oidcOPMetaDataOptionsStoreIDToken'
                         ]
                     },
                     {
@@ -189,6 +195,7 @@ sub cTrees {
                     'oidcRPMetaDataOptionsIDTokenExpiration',
                     'oidcRPMetaDataOptionsAccessTokenExpiration',
                     'oidcRPMetaDataOptionsRedirectUris',
+                    'oidcRPMetaDataOptionsBypassConsent',
                     'oidcRPMetaDataOptionsExtraClaims'
                 ]
             },
