@@ -13,7 +13,7 @@
 
 package Lemonldap::NG::Manager::Build::Tree;
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.6';
 
 # TODO: Missing:
 #  * activeTimer
@@ -264,7 +264,8 @@ sub tree {
                                         'ldapPwdEnc',
                                         'ldapUsePasswordResetAttribute',
                                         'ldapPasswordResetAttribute',
-                                        'ldapPasswordResetAttributeValue'
+                                        'ldapPasswordResetAttributeValue',
+                                        'ldapAllowResetExpiredPassword'
                                     ]
                                 },
                             ]
@@ -442,7 +443,16 @@ sub tree {
                                 'issuerDBOpenIDConnectPath',
                                 'issuerDBOpenIDConnectRule',
                             ]
-                        }
+                        },
+                        {
+                            title => 'issuerDBGet',
+                            nodes => [
+                                'issuerDBGetActivation',
+                                'issuerDBGetPath',
+                                'issuerDBGetRule',
+                                'issuerDBGetParameters'
+                            ]
+                        },
                     ]
                 },
                 {
@@ -471,6 +481,7 @@ sub tree {
                         'storePassword',
                         'timeout',
                         'timeoutActivity',
+                        'timeoutActivityInterval',
                         'grantSessionRules',
                         {
                             title => 'sessionStorage',
@@ -594,7 +605,8 @@ sub tree {
                                 'key',
                                 'trustedDomains',
                                 'useSafeJail',
-                                'checkXSS'
+                                'checkXSS',
+                                'lwpSslOpts'
                             ]
                         },
                         {
