@@ -80,6 +80,13 @@ function templates(tpl,key) {
                   "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsClientSecret",
                   "title" : "oidcOPMetaDataOptionsClientSecret",
                   "type" : "password"
+               },
+               {
+                  "default" : 0,
+                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsStoreIDToken",
+                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsStoreIDToken",
+                  "title" : "oidcOPMetaDataOptionsStoreIDToken",
+                  "type" : "bool"
                }
             ],
             "id" : "oidcOPMetaDataOptionsConfiguration",
@@ -337,6 +344,13 @@ function templates(tpl,key) {
             "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRedirectUris",
             "title" : "oidcRPMetaDataOptionsRedirectUris"
          },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsBypassConsent",
+            "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsBypassConsent",
+            "title" : "oidcRPMetaDataOptionsBypassConsent",
+            "type" : "bool"
+         },
          {
             "cnodes" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsExtraClaims",
             "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsExtraClaims",
@@ -367,6 +381,13 @@ function templates(tpl,key) {
    },
    {
       "_nodes" : [
+         {
+            "default" : "",
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsResolutionRule",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsResolutionRule",
+            "title" : "samlIDPMetaDataOptionsResolutionRule",
+            "type" : "longtext"
+         },
          {
             "default" : "",
             "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsNameIDFormat",
@@ -472,6 +493,13 @@ function templates(tpl,key) {
             ],
             "title" : "samlIDPMetaDataOptionsRequestedAuthnContext",
             "type" : "select"
+         },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRelayStateURL",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsRelayStateURL",
+            "title" : "samlIDPMetaDataOptionsRelayStateURL",
+            "type" : "bool"
          }
       ],
       "help" : "authsaml.html#options",
@@ -494,6 +522,13 @@ function templates(tpl,key) {
             "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsForceUTF8",
             "title" : "samlIDPMetaDataOptionsForceUTF8",
             "type" : "bool"
+         },
+         {
+            "default" : 0,
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsStoreSAMLToken",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsStoreSAMLToken",
+            "title" : "samlIDPMetaDataOptionsStoreSAMLToken",
+            "type" : "bool"
          }
       ],
       "id" : "samlIDPMetaDataOptionsSession",
@@ -510,7 +545,7 @@ function templates(tpl,key) {
             "type" : "trool"
          },
          {
-            "default" : 0,
+            "default" : 1,
             "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckSSOMessageSignature",
             "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckSSOMessageSignature",
             "title" : "samlIDPMetaDataOptionsCheckSSOMessageSignature",
@@ -524,7 +559,7 @@ function templates(tpl,key) {
             "type" : "trool"
          },
          {
-            "default" : 0,
+            "default" : 1,
             "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckSLOMessageSignature",
             "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckSLOMessageSignature",
             "title" : "samlIDPMetaDataOptionsCheckSLOMessageSignature",
@@ -632,10 +667,17 @@ function templates(tpl,key) {
             "type" : "select"
          },
          {
-            "default" : 0,
-            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckConditions",
-            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckConditions",
-            "title" : "samlIDPMetaDataOptionsCheckConditions",
+            "default" : 1,
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckTime",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckTime",
+            "title" : "samlIDPMetaDataOptionsCheckTime",
+            "type" : "bool"
+         },
+         {
+            "default" : 1,
+            "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckAudience",
+            "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsCheckAudience",
+            "title" : "samlIDPMetaDataOptionsCheckAudience",
             "type" : "bool"
          }
       ],
@@ -762,7 +804,7 @@ function templates(tpl,key) {
                   "type" : "trool"
                },
                {
-                  "default" : 0,
+                  "default" : 1,
                   "get" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsCheckSSOMessageSignature",
                   "id" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsCheckSSOMessageSignature",
                   "title" : "samlSPMetaDataOptionsCheckSSOMessageSignature",
@@ -776,7 +818,7 @@ function templates(tpl,key) {
                   "type" : "trool"
                },
                {
-                  "default" : 0,
+                  "default" : 1,
                   "get" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsCheckSLOMessageSignature",
                   "id" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsCheckSLOMessageSignature",
                   "title" : "samlSPMetaDataOptionsCheckSLOMessageSignature",
